//  $Id: empty_screen.cpp 855 2006-11-17 01:50:37Z coz $
//
//  SuperTuxKart - a fun racing game with go-kart
//  Copyright (C) 2006 SuperTuxKart-Team
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <SDL/SDL.h>

#include "empty_screen.hpp"
#include "start_screen.hpp"
#include "screen_manager.hpp"
#include "gui/menu_manager.hpp"

EmptyScreen::EmptyScreen()
{}

//-----------------------------------------------------------------------------
EmptyScreen::~EmptyScreen()
{}

//-----------------------------------------------------------------------------
void
EmptyScreen::update()
{
    menu_manager->update();

    SDL_GL_SwapBuffers();
}

/* EOF */
